# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid debug* files interfering with manifest test:
%global debug_package %{nil}

# Similarly for .package_note* files (#2062685)
%undefine _package_note_file

Name:		perl-Scalar-Properties
Version:	1.100860
Release:	34.%{__distinit}%{__distvers}
Summary:	Run-time properties on scalar variables
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Scalar-Properties
Source0:	https://cpan.metacpan.org/authors/id/M/MA/MARCEL/Scalar-Properties-%{version}.tar.gz
Patch3:		Scalar-Properties-1.100860-skip-MYMETA.yml.patch
BuildArch:	noarch
# ===================================================================
# Build requirements
# ===================================================================
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.11
# ===================================================================
# Module requirements
# ===================================================================
BuildRequires:	perl(overload)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# ===================================================================
# Test requirements
# ===================================================================
BuildRequires:	perl(Carp)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Test::More) >= 0.88
# ===================================================================
# Author test requirements
# (skipped as the Critic test fails in version 1.100860)
# ===================================================================
BuildRequires:	perl(English)
BuildConflicts:	perl(Test::Perl::Critic)
# ===================================================================
# Release test requirements
# (Spelling check can't find "versa" in version 1.100860)
# ===================================================================
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildConflicts:	perl(Pod::Wordlist::hanekomu)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::DistManifest)
BuildRequires:	perl(Test::HasVersion)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling)
BuildRequires:	perl(Test::Synopsis)
# ===================================================================
# Runtime dependencies
# ===================================================================
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Scalar::Properties attempts to make Perl more object-oriented by taking an idea
from Ruby: Everything you manipulate is an object, and the results of those
manipulations are objects themselves.

%prep
%setup -q -n Scalar-Properties-%{version}

# MANIFEST.SKIP should include MYMETA.yml; otherwise, t/release-dist-manifest.t
# may fail due to it appearing unexpectedly
%patch -P 3 -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test AUTHOR_TESTING=1 RELEASE_TESTING=1

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Scalar/
%{_mandir}/man3/Scalar::Properties.3*

%changelog
* Fri May 12 2023 Paul Howarth <paul@city-fan.org> - 1.100860-34
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Thu Mar 10 2022 Paul Howarth <paul@city-fan.org> - 1.100860-31
- Work around package note files breaking t/release-dist-manifest.t (#2062685)
- Use %%license unconditionally

* Sun Jun  9 2019 Paul Howarth <paul@city-fan.org> - 1.100860-18
- Perl 5.30 rebuild

* Fri Apr 13 2018 Paul Howarth <paul@city-fan.org> - 1.100860-14
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workarounds for building with Test::More < 0.88

* Fri Sep 23 2016 Paul Howarth <paul@city-fan.org> - 1.100860-10
- BR: perl-generators where available
- Simplify find command using -delete

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 1.100860-6
- Drop support for building with ExtUtils::MakeMaker < 6.30
- BR: perl(Test::Synopsis) unconditionally
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Sun Jul 15 2012 Paul Howarth <paul@city-fan.org> - 1.100860-2
- Update MYMETA.yml patch to include MYMETA.json too
- Drop non-dual-lived Perl core buildreqs
- Drop support for old distribution prior to FC-3:
  - Always BuildConflict with Test::Perl::Critic
  - Never need aspell-en-gb
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Feb 22 2012 Paul Howarth <paul@city-fan.org> - 1.100860-1
- Import from Fedora
- Update to 1.100860

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Jun 20 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.13-10
- Perl mass rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.13-8
- Rebuild to fix problems with vendorarch/lib (#661697)

* Thu May 06 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.13-7
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.13-6
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Nov 20 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.13-3
- Fix source url

* Wed Mar  5 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.13-2
- Rebuild for new perl

* Wed Dec 19 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.13-1.1
- BR: Test::More

* Wed Dec 19 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.13-1
- 0.13

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.12-1.1
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Sun Apr 09 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.12-1
- First build
